#
# spec file for package osinfo-db
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           osinfo-db
Version:        20250606
Release:        1.1
Summary:        Osinfo database files
License:        LGPL-2.1-or-later AND GPL-2.0-or-later
Group:          System/Management
URL:            https://gitlab.com/libosinfo/osinfo-db
Source:         https://releases.pagure.org/libosinfo/%{name}-%{version}.tar.xz
Patch21:        add-oes-support.patch
Patch22:        add-caasp40-support.patch
Patch23:        add-win-2k19-media-info.patch
Patch24:        fix-tumbleweed-order.patch
Patch25:        adjust-tumbleweed-hardware-requirements.patch
Patch28:        add-sle15sp7-support.patch
Patch30:        add-slem6.0-support.patch
Patch31:        add-slem6.1-support.patch
Patch32:        add-slem6.2-support.patch
Patch33:        add-sles16-support.patch
Patch34:        add-opensuse-leap-16.0-support.patch
BuildRequires:  intltool
BuildRequires:  osinfo-db-tools
BuildArch:      noarch

%description
The osinfo database provides information about operating systems and
hypervisor platforms to facilitate the automated configuration and
provisioning of new virtual machines

%prep
%autosetup -p1

%build
cd %{_builddir}
tar -cJf x.tar.xz osinfo-db-%{version}

%install
osinfo-db-import --root %{buildroot} --dir %{_datadir}/osinfo "%{_builddir}/x.tar.xz"

%files
%dir %{_datadir}/osinfo/
%{_datadir}/osinfo/VERSION
%{_datadir}/osinfo/LICENSE
%{_datadir}/osinfo/datamap
%{_datadir}/osinfo/device
%{_datadir}/osinfo/os
%{_datadir}/osinfo/platform
%{_datadir}/osinfo/install-script
%{_datadir}/osinfo/schema

%changelog
* Fri Jun 13 2025 carnold@suse.com
- Update to database version 20250606 (jsc#PED-12706)
  osinfo-db-20250606.tar.xz
- Drop add-Windows-Server-2025.patch
* Tue May 20 2025 carnold@suse.com
- bsc#1243296 - What version of virt-manager-common supports SLES16
  ISO layout
  add-sles16-support.patch
* Fri Mar 28 2025 carnold@suse.com
- bsc#1240121 - [SLEMicro6.2] osinfo-db: Add support for slem6.2 to
  the database
  add-slem6.2-support.patch
- bsc#1240338 - virt-manager: Windows Server 2025 is not
  automatically detected and missing from manual selection
  add-Windows-Server-2025.patch
* Thu Feb 27 2025 carnold@suse.com
- Modify SLES and Leap 16 database entries to define new volume id
  of Agama 12 ISOs (bsc#1236401)
  add-sles16-support.patch
  add-opensuse-leap-16.0-support.patch
* Fri Feb 21 2025 carnold@suse.com
- Add for SLES 16 / Leap 16, <firmware arch="x86_64" type="efi"/>
  add-sles16-support.patch
  add-opensuse-leap-16.0-support.patch
* Mon Jan 27 2025 carnold@suse.com
- Update to database version 20250124 (jsc#PED-8910)
  osinfo-db-20250124.tar.xz
- Drop patches contained in new tarball
  add-opensuse-leap-15.6-support.patch
  add-sle15sp6-support.patch
  add-slem5.5-support.patch
* Fri Jan 24 2025 carnold@suse.com
- Add support for openSUSE Leap 16.0 (jsc#PED-8910)
  add-opensuse-leap-16.0-support.patch
* Fri Jan 17 2025 carnold@suse.com
- Add support for SLES-16 (bsc#1236252) (jsc#PED-8910)
  add-sles16-support.patch
* Tue Sep 17 2024 carnold@suse.com
- Add support for SLE Micro 6.1 (jsc#PED-8910)
  add-slem6.1-support.patch
- Drop support for Leap 15.7. Next major version is Leap 16
  add-opensuse-leap-15.7-support.patch
- Adjust place holder release-date for sle15sp7
  add-sle15sp7-support.patch
* Wed Sep  4 2024 carnold@suse.com
- Add support for openSUSE Leap 15.7 (jsc#PED-8910)
  add-opensuse-leap-15.7-support.patch
- Add support for SLE-15-SP7 (jsc#PED-8910) (bsc#1230160)
  add-sle15sp7-support.patch
* Mon Jul  8 2024 carnold@suse.com
- Update the release dates in the definitions for the following
  products
  openSUSE leap 15.6, SLE 15-SP6, SLEM 5.5, SLEM 6.0
* Tue Jul  2 2024 carnold@suse.com
- Update to database version 20240701
  osinfo-db-20240701.tar.xz
* Mon Jul  1 2024 carnold@suse.com
- Adjust some default hardware requirements (bsc#1227231)
  adjust-tumbleweed-hardware-requirements.patch
  add-opensuse-leap-15.6-support.patch
  add-sle15sp6-support.patch
* Fri Jun 28 2024 carnold@suse.com
- bsc#1227116 - osinfo still uses deprecated SL-Micro name
  Reverse prior decision to drop the use of "Enterprise" in the
  name of the SUSE Linux Micro product.
  add-slem6.0-support.patch
  Drop add-slm6.0-support.patch
* Thu May 16 2024 carnold@suse.com
- Update to database version 20240510
  osinfo-db-20240510.tar.xz
* Tue May  7 2024 carnold@suse.com
- bsc#1222738 - virt-manager shows SLE Micro 6.0 in suggested OS
  version should be SL Micro 6.0
  add-slm6.0-support.patch
  Drop add-slem6.0-support.patch
* Thu Feb 15 2024 carnold@suse.com
- Add support for SLE Micro 6.0 (jsc#PED-6305)
  add-slem6.0-support.patch
* Wed Feb 14 2024 carnold@suse.com
- Add support for openSUSE Leap 15.6 (jsc#PED-6305)
  add-opensuse-leap-15.6-support.patch
* Fri Jan  5 2024 carnold@suse.com
- Update to database version 20231215 (jsc#PED-6305)
  osinfo-db-20231215.tar.xz
* Mon Nov 13 2023 carnold@suse.com
- Update to database version 20231027 (jsc#PED-6305)
  osinfo-db-20231027.tar.xz
* Mon Aug  7 2023 carnold@suse.com
- Update to database version 20230719
  osinfo-db-20230719.tar.xz
- Add support for SLE 15-SP6
  add-sle15sp6-support.patch
- Add support for SLE Micro 5.5
  add-slem5.5-support.patch
- Drop patches contained in new tarball
  add-opensuse-leap-15.5-support.patch
  add-sle15sp5-support.patch
  add-slem5.3-support.patch
  add-slem5.4-support.patch
* Wed May 31 2023 carnold@suse.com
- Update to database version 20230518
  osinfo-db-20230518.tar.xz
* Mon Mar 13 2023 carnold@suse.com
- Update to database version 20230308
  osinfo-db-20230308.tar.xz
* Thu Dec 15 2022 carnold@suse.com
- Update to database version 20221130
  osinfo-db-20221130.tar.xz
- Add support for SLE Micro 5.4
  add-slem5.4-support.patch
- Fix <derives-from id> value
  add-slem5.3-support.patch
* Thu Oct 27 2022 carnold@suse.com
- Update to database version 20221018
  osinfo-db-20221018.tar.xz
* Tue Oct  4 2022 carnold@suse.com
- jsc#PED-2113 [Virt Tools] Refresh Virtualization Tools for Xen
  and KVM Management
* Thu Sep 29 2022 carnold@suse.com
- Update to database version 20220830
  osinfo-db-20220830.tar.xz
* Fri Sep  2 2022 carnold@suse.com
- bsc#1202827 - Fail to deploy sle15sp5 guest via virt-install with
  osinfo
  add-sle15sp5-support.patch
* Thu Aug 25 2022 carnold@suse.com
- Add support for openSUSE Leap 15.5, SLES 15.5, and SLE Micro 5.3
  add-opensuse-leap-15.5-support.patch
  add-sle15sp5-support.patch
  add-slem5.3-support.patch
* Mon Aug  1 2022 Dirk Müller <dmueller@suse.com>
- update to 20220727
- drop: add-opensuse-leap-15.4-support.patch
  add-sle15sp4-support.patch
  add-slem5.1-support.patch
  add-slem5.2-support.patch
  opensuse-autoyast-desktop.patch: all upstream
* Mon May 23 2022 carnold@suse.com
- Update to database version 20220516
  osinfo-db-20220516.tar.xz
* Tue Apr  5 2022 carnold@suse.com
- bsc#1197958 - request support for SLE15-SP4 in the osinfo database
- Add support for SUSE linux Enterprise Micro 5.2
  add-slem5.2-support.patch
* Thu Mar 10 2022 carnold@suse.com
- bsc#1196965 - openSUSE Tumbleweed unattended installation with
  libvirt fails
  opensuse-autoyast-desktop.patch
* Tue Mar  1 2022 carnold@suse.com
- Update to database version 20220214
  osinfo-db-20220214.tar.xz
* Wed Jan  5 2022 carnold@suse.com
- Update to database version 20211216
  osinfo-db-20211216.tar.xz
- Drop add-missing-oracle-linux-versions.patch
* Tue Nov 23 2021 carnold@suse.com
- jsc#SLE-17764 - Dev: Support Oracle Linux as a guest VM. See also
  bsc#1192238 [Build58.2][KVM] The latest supported OracleLinux as
  guest versions are not included anywhere
  add-missing-oracle-linux-versions.patch
* Wed Oct 20 2021 carnold@suse.com
- Update to database version 20211013
  osinfo-db-20211013.tar.xz
* Fri Sep  3 2021 carnold@suse.com
- Update to database version 20210903
  osinfo-db-20210903.tar.xz
* Wed Sep  1 2021 carnold@suse.com
- Update to database version 20210809
  osinfo-db-20210809.tar.xz
* Tue Jul 27 2021 carnold@suse.com
- bsc#1182144 - osinfo-db: autoinst.xml does not work with
  Tumbleweed. Fixes nested language problem.
  opensuse-autoyast-desktop.patch
* Mon Jul 26 2021 carnold@suse.com
- Add support for openSUSE Leap 15.4, SLE15-SP4, and SLEM 5.1
  (bsc#1188692)
  add-opensuse-leap-15.4-support.patch
  add-sle15sp4-support.patch
  add-slem5.1-support.patch
* Mon Jul 19 2021 carnold@suse.com
- bsc#1188336 - openSUSE Tumbleweed unattended installation in
  libvirt fails due to invalid autoyast.xml
  Drop fix-autoyast-validation.patch
* Mon Jun 21 2021 carnold@suse.com
- Update to database version 20210621
  osinfo-db-20210621.tar.xz
- Drop patches contained in new tarball
  SLE-add-info-about-UEFI-support.patch
  add-sle15sp3-support.patch
  add-slem50-support.patch
  fix-sle15sp1-volume-id-string.patch
* Fri Jun 11 2021 carnold@suse.com
- Update to database version 20210531
  osinfo-db-20210531.tar.xz
- Drop add-leap15.3-support.patch
* Mon Apr 12 2021 carnold@suse.com
- Add support for SUSE Linux Enterprise Micro. See also patch
  in virt-manager to enable media detection.
  add-slem-support.patch
* Fri Apr  9 2021 carnold@suse.com
- Update to database version 20210312
  osinfo-db-20210312.tar.xz
* Tue Mar  2 2021 carnold@suse.com
- Update to database version 20210215
  osinfo-db-20210215.tar.xz
* Tue Mar  2 2021 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Fix AutoYaST profiles to pass the validation during installation
  (bsc#1182144).
  fix-autoyast-validation.patch
* Tue Jan 12 2021 carnold@suse.com
- Update database to version 20201218
  osinfo-db-20201218.tar.xz
* Mon Oct 26 2020 carnold@suse.com
- Update database to version 20201015
  osinfo-db-20201015.tar.xz
* Thu Sep  3 2020 carnold@suse.com
- Update database to version 20200813
  osinfo-db-20200813.tar.xz
* Fri Aug 14 2020 carnold@suse.com
- Add support for openSUSE Leap 15.3 and SLE15-SP3
  add-leap15.3-support.patch
  add-sle15sp3-support.patch
* Fri Aug  7 2020 carnold@suse.com
- Update database to version 20200804
- Drop patches included in new tarball
  add-opensuse-leap-15.2-support.patch
  add-sle15sp2-support.patch
* Wed Jul  1 2020 Frederic Crozat <fcrozat@suse.com>
- Add fix-tumbleweed-order.patch: ensure x86_64 is listed before
  i686, to have x86_64 selected by default in GNOME Boxes
- Update url with gitlab home for osinfo-db.
* Mon Jun  1 2020 carnold@suse.com
- Update database to version 20200529
- Drop 5bbe30db-opensuse-add-info-about-UEFI-support.patch
* Fri May 22 2020 carnold@suse.com
- bsc#1172008 - osinfo-db: Add support for openSUSE Leap 15.2
  add-opensuse-leap-15.2-support.patch
* Thu Mar  5 2020 carnold@suse.com
- bsc#1165855 - Add UEFI support to the database for SLES and
  openSUSE distros
  5bbe30db-opensuse-add-info-about-UEFI-support.patch
  SLE-add-info-about-UEFI-support.patch
* Tue Mar  3 2020 carnold@suse.com
- Update database to version 20200214
  osinfo-db-20200214.tar.xz
- Drop patch included in new tarball
  add-sle12sp5-support.patch
* Wed Feb 26 2020 carnold@suse.com
- Fix the length of string for the ISO volume id (bsc#1054986)
  fix-sle15sp1-volume-id-string.patch
  add-sle15sp2-support.patch
- Fix release date of SLE12-SP5
  add-sle12sp5-support.patch
* Thu Jan  2 2020 carnold@suse.com
- bsc#1159445 - [virt-manager] Detected the wrong win guest system
  version from the local install media
  add-win-2k19-media-info.patch
* Mon Dec  2 2019 carnold@suse.com
- Update database to version 20191125
  osinfo-db-20191125.tar.xz
- Update sle12sp5 definition
  add-sle12sp5-support.patch
* Wed Nov 13 2019 carnold@suse.com
- Update database to version 20191108
  osinfo-db-20191108.tar.xz
* Tue Oct  1 2019 carnold@suse.com
- Update database to version 20190920
  osinfo-db-20190920.tar.xz
* Wed Sep 18 2019 carnold@suse.com
- Update database to version 20190905
  osinfo-db-20190905.tar.xz
* Wed Sep  4 2019 carnold@suse.com
- Update database to version 20190805
  osinfo-db-20190805.tar.xz
- Add support for SLE15-SP2
  add-sle15sp2-support.patch
* Fri Jul 26 2019 carnold@suse.com
- Update database to version 20190726
  osinfo-db-20190726.tar.xz
- Drop add-sle15sp1-support.patch
* Wed Jul 17 2019 carnold@suse.com
- Update database to version 20190611
  osinfo-db-20190611.tar.xz
- Drop add-sle12sp4-support.patch
* Thu Jun  6 2019 carnold@suse.com
- Add official release date for sle15sp1
  add-sle15sp1-support.patch
* Thu May  9 2019 carnold@suse.com
- Update database to version 20190504
  osinfo-db-20190504.tar.xz
- Drop add-opensuse-leap-15.1-support.patch
* Tue Apr 23 2019 carnold@suse.com
- Add support for sle12sp5
  add-sle12sp5-support.patch
* Wed Apr 10 2019 carnold@suse.com
- Update database to version 20190319
  osinfo-db-20190319.tar.xz
* Wed Mar 13 2019 carnold@suse.com
- Add support for Caasp40 media
  add-caasp40-support.patch
* Fri Mar  1 2019 carnold@suse.com
- Update database to version 20190301
  osinfo-db-20190301.tar.xz
* Mon Feb  4 2019 carnold@suse.com
- Update database to version 20190120
  osinfo-db-20190120.tar.xz
* Thu Jan  3 2019 carnold@suse.com
- Fix volume ID for SLE15-SP1 (bsc#1086715)
  add-sle15sp1-support.patch
  add-opensuse-leap-15.1-support.patch
* Tue Dec 18 2018 carnold@suse.com
- Add correct release date for SLE12-SP4
  add-sle12sp4-support.patch
* Fri Nov 30 2018 carnold@suse.com
- Update database to version 20181116
  osinfo-db-20181116.tar.xz
* Fri Oct 12 2018 Fabiano Fidêncio <fabiano@fidencio.org>
- Update database to version 20181011
  osinfo-db-20181011.tar.xz
- Drop add-caasp-support.patch
- Drop modify-volume-id-for-windows.patch
* Wed Oct 10 2018 carnold@suse.com
- Add support for sle15sp1 (bsc#1086715)
  add-sle15sp1-support.patch
* Tue Oct  2 2018 carnold@suse.com
- Update database to version 20180920
  osinfo-db-20180920.tar.xz
* Mon Sep  3 2018 fabiano@fidencio.org
- Update database to version 20180903
  osinfo-db-20180903.tar.xz
* Fri Jul 27 2018 carnold@suse.com
- bsc#1102101 - osinfo-db: Add support for sle12sp4 to the database
  add-sle12sp4-support.patch
* Fri Jul 20 2018 fabiano@fidencio.org
- Update database to version 20180720
  osinfo-db-20180720.tar.xz
- Drop add-sle15-support.patch
* Fri Jul 13 2018 carnold@suse.com
- Add official release date for sle15. Drop 'sles' and 'sled' in
  favor of just 'sle' (bsc#1054986)
  add-sle15-support.patch
* Tue Jun 19 2018 carnold@suse.com
- bsc#1098054 - osinfo-query and virt-install do not detect
  caasp3.0
  add-caasp-support.patch
* Tue Jun 12 2018 fabiano@fidencio.org
- Update database to version 20180612
  osinfo-db-20180612.tar.xz
* Thu May 31 2018 fabiano@fidencio.org
- Update database to version 20180531
  osinfo-db-20180531.tar.xz
- Drop add-opensuse-leap-15-support.patch
* Mon May 14 2018 fabiano@fidencio.org
- Update database to version 20180514
  osinfo-db-20180514.tar.xz
* Wed May  2 2018 fabiano@fidencio.org
- Update database to version 20180502
  osinfo-db-20180502.tar.xz
* Mon Apr 16 2018 fabiano@fidencio.org
- fate#322156 - Update database to version 20180416
  osinfo-db-20180416.tar.xz
* Wed Apr  4 2018 lyan@suse.com
- bsc#974580 - modify volume id for some windows iso files
  First, use "X64FREE?" instead of "X64FRE".
  Second, add "IR1_SSS_X64FREV_EN-US_DV5".
  modify-volume-id-for-windows.patch
* Fri Mar 23 2018 carnold@suse.com
- bsc#1086715 - SLE15 patch for osinfo-db has wrong information
  in it
  add-sle15-support.patch
* Mon Mar 19 2018 carnold@suse.com
- bsc#1085757 - Leap 15 patch for osinfo-db has wrong information
  in it
  add-opensuse-leap-15-support.patch
* Wed Mar 14 2018 carnold@suse.com
- fate#322156 - Update database to version 20180311
  osinfo-db-20180311.tar.xz
- Drop
  add-opensuse-leap-42.3-support.patch
  add-sle12sp3-support.patch
  add-win2k16-support.patch
* Tue Dec 19 2017 carnold@suse.com
- Fix version string for leap 15 (bsc#1054986)
  add-opensuse-leap-15-support.patch
* Fri Sep  8 2017 carnold@suse.com
- bsc#1057733 - libosinfo db entry for caasp wrong
  add-caasp-support.patch
* Tue Aug 29 2017 carnold@suse.com
- bsc#1056028 - Not able to install OES2018 as guest on Xen
  add-oes-support.patch
* Wed Aug 16 2017 carnold@suse.com
- Add support for openSUSE Leap 15 and SLE15 (bsc#1054986)
  add-opensuse-leap-15-support.patch
  add-sle15-support.patch
* Mon Aug 14 2017 carnold@suse.com
- fate#322156 - Update database to version 20170813
  osinfo-db-20170813.tar.xz
* Tue Jun 13 2017 carnold@suse.com
- fate#322156 - Update database to version 20170423
  osinfo-db-20170423.tar.xz
* Mon Apr 10 2017 cbosdonnat@suse.com
- casp is actually written CaasP.
  Rename patch add-casp-support.patch into add-caasp-support.patch
* Wed Mar 29 2017 carnold@suse.com
- bsc#1030538 - osinf-db: casp-1.xml should be called casp-1.0.xml
  add-casp-support.patch
- fate#322156 - Update to version 20170326
  osinfo-db-20170326.tar.xz
- Dropped patches now in new tarball
  99f7e666-fix-opensuse-derives-from-information.patch
  470b7652-add-opensuse-device-information.patch
  3c621fd8-add-opensuse-date-information.patch
  e77abec7-add-opensuse-resource-information.patch
  67c74e5f-add-opensuse-leap-42.2-support.patch
  f0d44d88-add-missing-sle10-distros.patch
  9a35cea7-fix-sle-derives-from-information.patch
  50091807-add-sle-device-information.patch
  9dec2be8-add-sle-date-information.patch
  1a7ce161-add-sle-resource-information.patch
  99ae3d72-add-sle12sp2-support.patch
* Fri Mar  3 2017 carnold@suse.com
- fate#322156 - Virtualization: Supported Virtualizated Guests
  add-win2k16-support.patch
* Fri Jan 27 2017 jengelh@inai.de
- Use more appropriate RPM group
- Avoid overwriting sources during build
* Fri Jan 13 2017 carnold@suse.com
- bsc#1010060 - virt-install won't start CASP installation
  add-casp-support.patch
* Tue Dec  6 2016 carnold@suse.com
- bsc#1013983 - incomplete capabilities list of SLE and openSUSE
  distributions in libosinfo
  99f7e666-fix-opensuse-derives-from-information.patch
  470b7652-add-opensuse-device-information.patch
  3c621fd8-add-opensuse-date-information.patch
  e77abec7-add-opensuse-resource-information.patch
  67c74e5f-add-opensuse-leap-42.2-support.patch
  f0d44d88-add-missing-sle10-distros.patch
  9a35cea7-fix-sle-derives-from-information.patch
  50091807-add-sle-device-information.patch
  9dec2be8-add-sle-date-information.patch
  1a7ce161-add-sle-resource-information.patch
  99ae3d72-add-sle12sp2-support.patch
- Dropped or renamed
  Fix_derives-from_and_add_tablet_item.patch
  add-opensuse-leap-42.2-support.patch
  add-sle12sp2-support.patch
  add-sle12sp2-support-for-arch.patch
  add-missing-sle10-distros.patch
* Thu Dec  1 2016 carnold@suse.com
- Update to database version 20161026
  osinfo-db-20161026.tar.xz
* Thu Dec  1 2016 carnold@suse.com
- bsc#1012005 - [openqa virtualization] using the wrong bootloader
  tool to boot the sles-12-sp3 pv kernel on xen platform
  add-sle12sp3-support.patch
  add-opensuse-leap-42.3-support.patch
* Tue Oct 11 2016 carnold@suse.com
- bsc#1003456 - virt-install fails to detect openSUSE Leap 42.2 ISO
  add-opensuse-leap-42.2-support.patch
- bsc#1000188 - virt-install on aarch64 does not detect
  installation iso
  add-sle12sp2-support-for-arch.patch
- bsc#986731 - libosinfo: Add support for openSUSE Leap 42.2
  add-opensuse-leap-42.2-support.patch
- bsc#979369 - libosinfo: Missing sle10 distro versions
  add-missing-sle10-distros.patch
- bsc#946157 - The mouse cursor doesn't work during Guest OS
  installation in KVM Mode
  Fix_derives-from_and_add_tablet_item.patch
* Mon Oct 10 2016 carnold@suse.com
- Version 20160728
  The osinfo database provides information about operating systems and
  hypervisor platforms to facilitate the automated configuration and
  provisioning of new virtual machines
